#delimit ;
*analysis_prev_dd.do ;
capture log close ;
log using "F:\Schwartz\cps_historical\do\edcats\analysis_prev_dd.log",replace ;
set more 1 ;
clear ;
program drop _all ;
set mem 600m ;
set matsize 6000 ;




use "F:\Schwartz\cps_historical\data\couples_tab_dd.dta" ;


*********************************************************************
* FILE PURPOSE:  This file runs log-linear homogamy, crossings,     *
*                and uniform association models for detailed        *
*                education classifications. The categories are:     *
*                < 5                                                *
*                5-9                                                *
*                10-11                                              *
*                12                                                 *
*                13-15                                              *
*                16                                                 *
*                gt 16                                              *
********************************************************************* ;



#delimit cr

collapse (sum) WEIGHT freq, by(wedc hedc y cps)


tab y cps [w=freq]


display _N

preserve
collapse (sum) freq, by(y cps)
display _N
restore



*******************************
* SECTION 1: CREATE VARIABLES *
*******************************


   **Look at the education variable

     tab wedc



   **Recode into 7 category variable

     recode wedc 1/2=1 3/4=2 5/6=3 7=4 8=5 9=6 10=7
     recode hedc 1/2=1 3/4=2 5/6=3 7=4 8=5 9=6 10=7

     collapse (sum) WEIGHT freq, by(wedc hedc y cps)


   ***Recode year into four digits

      replace y = y + 1900



   ***Look at the file

      tab y cps [w=freq]




   ***Create an indicator for new vs. old ed question.


   gen newed = ((cps == 1 & y >= 1992)  | (cps == 0 & y >= 1990))

   bysort cps: tab y newed



   ***Census indicator


      gen cen = (cps == 0 )

      tab y cen [w=freq]



   ***homogamy

      gen h = (hed == wed)


   ***Education specific homogamy

      gen h1 = (hed == wed & hed == 1)
      gen h2 = (hed == wed & hed == 2)
      gen h3 = (hed == wed & hed == 3)
      gen h4 = (hed == wed & hed == 4)
      gen h5 = (hed == wed & hed == 5)
      gen h6 = (hed == wed & hed == 6)
      gen h7 = (hed == wed & hed == 7)



   ***Make the crossing variables

       gen dc1 = 0
       replace dc1 = 1 if (wed < 2 & hed>= 2) | (hed< 2 & wed >= 2)

       gen dc2 = 0
       replace dc2 = 1 if (wed < 3 & hed>= 3) | (hed< 3 & wed >= 3)

       gen dc3 = 0
       replace dc3= 1 if (wed < 4 & hed>= 4) | (hed< 4 & wed >= 4)

       gen dc4 = 0
       replace dc4 = 1 if (wed < 5 & hed>= 5) | (hed< 5 & wed >= 5)

       gen dc5 = 0
       replace dc5 = 1 if (wed < 6 & hed>= 6) | (hed< 6 & wed >= 6)

       gen dc6 = 0
       replace dc6 = 1 if (wed < 7 & hed>= 7) | (hed< 7 & wed >= 7)




   ***Make a uniform association parameter.



      gen hl = .
      replace hl = 4    if hed == 1
      replace hl = 8    if hed == 2
      replace hl = 10.5 if hed == 3
      replace hl = 12   if hed == 4
      replace hl = 14   if hed == 5
      replace hl = 16   if hed == 6
      replace hl = 18   if hed == 7

      gen wl = .
      replace wl = 4    if hed == 1
      replace wl = 8    if hed == 2
      replace wl = 10.5 if hed == 3
      replace wl = 12   if hed == 4
      replace wl = 14   if hed == 5
      replace wl = 16   if hed == 6
      replace wl = 18   if hed == 7



   ***The uniform association parameter is hl*wl

      gen ua = hl*wl



   ****Generate hypergamy parameter

       gen hyp = (hed>wed)



  ***Two-way interactions

     *HY and WY

     foreach num of numlist 1960 1962 1964/2003 {
       local i = 2
        while `i' <= 7 {
           gen h`i'y`num' = (hedc == `i' & y == `num')
           gen w`i'y`num' = (wedc == `i' & y == `num')
       local i = `i' + 1
       }
     }


      *HW

       local i = 2
        while `i' <= 7 {
         local j = 2
          while `j' <= 7 {
           gen h`i'w`j' = (hedc == `i' & wedc == `j')
         local j = `j' + 1
         }
       local i = `i' + 1
       }


      *HCPS and WCPS

       local i = 2
        while `i' <= 7 {
           gen h`i'cen = (hedc == `i' & cen == 1)
           gen w`i'cen = (wedc == `i' & cen == 1)
       local i = `i' + 1
       }



      *YCPS

     foreach num of numlist 1960 1970 1980 1990 2000 {
         gen y`num'cen = (cen == 1 & y == `num')
     }





   ***Make a three way interaction for the marginals of husband's and
   ***wife's education by year and data source


     foreach num of numlist 1960 1962 1964/2003 {
       local i = 1
        while `i' <= 7 {
           gen h`i'y`num'cen = (hedc == `i' & cen == 1 & y == `num')
       local i = `i' + 1
       }
     }

     foreach num of numlist 1940 1960 1962 1964/2003 {
       local i = 1
        while `i' <= 7 {
           gen w`i'y`num'cen = (wedc == `i' & cen == 1 & y == `num')
       local i = `i' + 1
       }
     }


       local i = 1
        while `i' <= 7 {
         local j = 1
          while `j' <= 7 {
           gen h`i'w`j'ycen = (hedc == `i' & wedc == `j' & cen == 1)
         local j = `j' + 1
         }
       local i = `i' + 1
       }



     *HomSpecific*Y

     foreach num of numlist 1960 1962 1964/2003 {
       local i = 1
        while `i' <= 7 {
           gen hm`i'y`num' = (h`i' == 1 & y == `num')
       local i = `i' + 1
       }
     }

     *Hom/UA*Census

      gen hcen = (h == 1 & cen   == 1)
      gen uacen = (ua * cen)

     *DC*Census

       local i = 1
        while `i' <= 6 {
           gen dc`i'cen = (dc`i' == 1 & cen   == 1)
       local i = `i' + 1
       }




   #delimit ;


   ******************
   * WEIGHTING CODE *
   ****************** ;


   ***To weight the data, follow Agresti page 391 section 9.7.5.

      zi = the total weighted frequency divided by the cell
      count.  In my case, this is:

      WEIGHT/freq = zi

      Loglinear models for the weighted expected frequencies
      (zi*mui = mui/ti) with ti = 1/zi expresses the model as
      a standard loglinear model for logmui with offset
      (logti = -logzi).

      What this means is the offset is equal to:

      -ln(zi)

      crs 2/25/04 ;


   #delimit cr


   gen zi      = (WEIGHT/freq)
   gen neglnzi = -ln(zi)




   set matsize 6000





***************************************
* SECTION 2: MAKE MACROS FOR MODELING *
***************************************





   #delimit ;

   local hycen "h2y1970cen
                h2y1980cen
                h2y1990cen
                h2y2000cen
                h3y1970cen
                h3y1980cen
                h3y1990cen
                h3y2000cen
                h4y1970cen
                h4y1980cen
                h4y1990cen
                h4y2000cen
                h5y1970cen
                h5y1980cen
                h5y1990cen
                h5y2000cen
                h6y1970cen
                h6y1980cen
                h6y1990cen
                h6y2000cen
                h7y1970cen
                h7y1980cen
                h7y1990cen
                h7y2000cen";

   local wycen "w2y1970cen
                w2y1980cen
                w2y1990cen
                w2y2000cen
                w3y1970cen
                w3y1980cen
                w3y1990cen
                w3y2000cen
                w4y1970cen
                w4y1980cen
                w4y1990cen
                w4y2000cen
                w5y1970cen
                w5y1980cen
                w5y1990cen
                w5y2000cen
                w6y1970cen
                w6y1980cen
                w6y1990cen
                w6y2000cen
                w6y1970cen
                w6y1980cen
                w6y1990cen
                w6y2000cen
                w7y1970cen
                w7y1980cen
                w7y1990cen
                w7y2000cen
                w7y1970cen
                w7y1980cen
                w7y1990cen
                w7y2000cen" ;



   local hwf "h2w2
              h2w3
              h2w4
              h2w5
              h2w6
              h2w7
              h3w2
              h3w3
              h3w4
              h3w5
              h3w6
              h3w7
              h4w2
              h4w3
              h4w4
              h4w5
              h4w6
              h4w7
              h5w2
              h5w3
              h5w4
              h5w5
              h5w6
              h5w7
              h6w2
              h6w3
              h6w4
              h6w5
              h6w6
              h6w7
              h7w2
              h7w3
              h7w4
              h7w5
              h7w6
              h7w7" ;






****************************************
* HOMOGAMY                             *
**************************************** ;







  *** MODEL: HYS, WYS, HWS HomY ***  ;

    gen f03 = freq ;


    xi: glm f03
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y
                   cen

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  `hwf'           /*HW*/
                  h?cen          /*HS*/
                  w?cen          /*WS*/
                  y????cen       /*SY*/

                 /*three-way interactions, HWS HYS WYS*/
                 `whc'     /*HWS*/
                 `wycen'   /*WYS*/
                 `hycen'   /*HYS*/

                  /* homogamy*/
                   i.y*h


                  , family(poisson) link(log) offset(neglnzi)  ;



    matrix b=e(b) ;
    svmat b, n(eqcol) ;




  *** MODEL: SAME AS ABOVE BUT NO HW ***  ;

    gen f40 = freq ;


    xi: glm f40
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y
                   cen

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  h?cen          /*HS*/
                  w?cen          /*WS*/
                  y????cen       /*SY*/

                 /*three-way interactions, HWS HYS WYS HWN*/
                  hcen     /*HWS*/
                 `wycen'   /*WYS*/
                 `hycen'   /*HYS*/

                  /* homogamy*/
                   i.y*h


                  , family(poisson) link(log) offset(neglnzi)  ;



    #delimit cr



    matrix b=e(b)
    svmat b, n(eqcol)



    ****CREATE ODDS***********


       gen e_hm1940 = exp(f40h)

       foreach num of numlist 1960 1962 1964/2003 {
         quietly gen e_hm`num' = exp(f40h + f03_IyXh_`num')
       }






   drop f40* f03*



#delimit ;



****************************************
* UNIFORM ASSOCIATION                  *
**************************************** ;



  *** MODEL: HYS, WYS, HWS, UAY ***  ;

    gen f03 = freq ;


    xi: glm f03
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y
                   cen

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  `hwf'           /*HW*/
                  h?cen          /*HS*/
                  w?cen          /*WS*/
                  y????cen       /*SY*/

                 /*three-way interactions, HWS HYS WYS*/
                 `whc'     /*HWS*/
                 `wycen'   /*WYS*/
                 `hycen'   /*HYS*/

                  /* uniform association*/
                   i.y*ua


                  , family(poisson) link(log) offset(neglnzi)  ;




    matrix b=e(b) ;
    svmat b, n(eqcol) ;




  *** MODEL: SAME AS ABOVE BUT NO HW ***  ;

    gen f40 = freq ;


    xi: glm f40
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y
                   cen

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  h?cen          /*HS*/
                  w?cen          /*WS*/
                  y????cen       /*SY*/

                 /*three-way interactions, HWS HYS WYS*/
                  uacen    /*HWS*/
                 `wycen'   /*WYS*/
                 `hycen'   /*HYS*/

                  /* uniform assocation*/
                   i.y*ua


                  , family(poisson) link(log) offset(neglnzi)  ;



    #delimit cr



    matrix b=e(b)
    svmat b, n(eqcol)



    ****CREATE ODDS***********


       gen e_uam1940 = exp(f40ua)

       foreach num of numlist 1960 1962 1964/2003 {
         quietly gen e_uam`num' = exp(f40ua + f03_IyXua_`num')
       }




   drop f40* f03*

#delimit ;




****************************************
* CROSSINGS                            *
**************************************** ;



  *** MODEL: HYS, WYS, HWS, CY ***  ;

    gen f03 = freq ;


    xi: glm f03
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y
                   cen

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  `hwf'           /*HW*/
                  h?cen          /*HS*/
                  w?cen          /*WS*/
                  y????cen       /*SY*/

                 /*three-way interactions, HWS HYS WYS*/
                 `whc'     /*HWS*/
                 `wycen'   /*WYS*/
                 `hycen'   /*HYS*/

                  /* crossings*/
                   i.y*dc1 i.y*dc2 i.y*dc3 i.y*dc4  i.y*dc5   i.y*dc6


                  , family(poisson) link(log) offset(neglnzi)  ;





    matrix b=e(b) ;
    svmat b, n(eqcol) ;




  *** MODEL: SAME AS ABOVE BUT NO HW ***  ;

    gen f40 = freq ;


    xi: glm f40
                 /*marginals*/
                   i.hed
                   i.wed
                   i.y
                   cen

                 /*all two-way interactions, HY WY HW HS WS SY*/
                  h?y????        /*HY*/
                  w?y????        /*WY*/
                  h?cen          /*HS*/
                  w?cen          /*WS*/
                  y????cen       /*SY*/

                 /*three-way interactions, HWS HYS WYS HWN*/
                  dc?cen   /*HWS*/
                 `wycen'   /*WYS*/
                 `hycen'   /*HYS*/

                  /* crossings*/
                   i.y*dc1 i.y*dc2 i.y*dc3 i.y*dc4  i.y*dc5   i.y*dc6


                  , family(poisson) link(log) offset(neglnzi)  ;



    #delimit cr



    matrix b=e(b)
    svmat b, n(eqcol)



    ****CREATE ODDS***********


       foreach dc of numlist 1/6 {

         gen e_dc`dc'm1940 = exp(f40dc`dc')

         foreach num of numlist 1960 1962 1964/2003 {
           quietly gen e_dc`dc'm`num' = exp(f40dc`dc' + f03_IyXdc`dc'_`num')
         }


     }



   drop f40* f03*







  *** GRAPH  ***

    keep e_h* e_ua* e_dc*
    keep in 1

    gen id = 1


    #delimit ;

    reshape long e_hm e_uam e_dc1m e_dc2m e_dc3m e_dc4m e_dc5m e_dc6m, i(id) j(year) ;

    #delimit cr



      lab var e_hm    "HY WY HW HmY"
      lab var e_uam   "HY WY HW UaY"
      label var e_dc1m "lt 5/5-9"
      label var e_dc2m "5-9/10-11"
      label var e_dc3m "10-11/12"
      label var e_dc4m "12/13-15"
      label var e_dc5m "13-15/16"
      label var e_dc6m "16/gt 16"



    cd "F:\Schwartz\cps_historical\graphs"


    ***HOMOGAMY***

     #delimit ;
     twoway connected  e_hm year,
                      yscale(log r(2.5 4.5)) clstyle(p2 p2 p2 p2 p2 p2) ylabel(2.5(.5)4.5, grid)
                      scheme(s1color)
                      msize(medsmall medium medium medium)
                      clpattern(llll) clcolor(gs0 gs0 gs0 gs0) mcolor(gs0 gs0 gs0 gs0)
                      graphregion(fcolor(gs16)) plotregion(style(none))
                      title("Odds of Homogamy") sub("Prevailing Marriages (Wives 18-40)")
                      ytitle("Odds of homogamy") xtitle("Year")
                     note("SOURCES: Current Population Survey (CPS) and Census data."
                        "NOTE: Education categories are lt 5, 5-9,10-11, 12, 13-15, 16, and gt 16 years of schooling.") ;

    #delimit cr

    graph export analysis_prev_dd1.wmf, replace




    ***UAY***

    #delimit ;
    twoway connected e_uam year, yscale(log ) c(l) clstyle(p2 p2 p2 p2 p2 p2)
                                    mcolor(blue red brown purple lime gs4)
                                    clcolor(blue red brown purple lime gs4)
                                    xlabel(#15)
                                    title("HY WY HW UaY") sub("Prev M, Women 16-40, WEIGHTED")
                                    ytitle("Uniform Association") xtitle("year") ;
    #delimit cr

    graph export analysis_prev_dd2.wmf, replace





    ***CROSSINGS***


#delimit ;
     twoway connected  e_dc1m e_dc2m e_dc3m year,
                      yscale(log r(.15 .7)) clstyle(p2 p2 p2 p2 p2 p2) ylabel(.15(.1).7, grid)
                      scheme(s1color)
                      msymbol(T O Dh X)
                      msize(medsmall medium medium medium)
                      clpattern(llll) clcolor(gs0 gs0 gs0 gs0) mcolor(gs0 gs0 gs0 gs0)
                      graphregion(fcolor(gs16)) plotregion(style(none))
                      xlabel(#15)   title(" ", size(medlarge) color(gs0)) sub(" ")
                      ytitle("Odds of Crossing") xtitle("Year") legend(rows(1)) ;

      cd "F:\Schwartz\cps_historical\graphs" ;
    #delimit cr
    graph export analysis_prev_dd4.wmf, replace



     #delimit ;
     twoway connected /* e_dc1m e_dc2m */ e_dc4m e_dc5m e_dc6m year,
                      yscale(log r(.15 .7)) clstyle(p2 p2 p2 p2 p2 p2) ylabel(.15(.1).7, grid)
                      scheme(s1color)
                      msymbol(X D Th )
                      msize(medium medsmall medium medium medium medium)
                      clpattern(llll) clcolor(gs0 gs0 gs0 gs0) mcolor(gs0 gs0 gs0 gs0)
                      graphregion(fcolor(gs16)) plotregion(style(none))
                      xlabel(#15)   title(" ", size(medlarge) color(gs0)) sub(" ")
                      ytitle("Odds of Crossing") xtitle("Year") legend(rows(1)) ;

      cd "F:\Schwartz\cps_historical\graphs" ;
    #delimit cr




#delimit ;


