#delimit ;
*desc_d.do ;
capture log close ;
log using "F:\Schwartz\cps_historical\do\edcats\desc_d.log",replace ;
set more 1 ;
clear ;
program drop _all ;
set mem 600m ;
set matsize 6000 ;



********PROGRAM PURPOSE*********



********************************  ;


#delimit cr


use "F:\Schwartz\cps_historical\data\couples_tab_d.dta"



#delimit cr


gen cen= (cps==0)


gen h = (hedc_d == wedc_d)
gen hyp = (hedc_d > wedc_d)
gen het = (hedc_d ~= wedc_d)
replace y = y + 1900
gen d = abs(hedc-wedc)
gen d2 = (d >= 2)


#delimit ;

***To weight the data, follow Agresti page 391 section 9.7.5.

   zi = the total weighted frequency divided by the cell
   count.  In my case, this is:

   WEIGHT/freq = zi

   Loglinear models for the weighted expected frequencies
   (zi*mui = mui/ti) with ti = 1/zi expresses the model as
   a standard loglinear model for logmui with offset
   (logti = -logzi).

   What this means is the offset is equal to:

   -ln(zi)

   crs 2/25/04 ;


#delimit cr


gen zi      = (WEIGHT/freq)
gen neglnzi = -ln(zi)



preserve

    keep h y WEIGHT cps freq

    collapse h [w=WEIGHT], by(y cps)

replace h = h*100

gen hcps = h if cps == 1
gen hcen = h if cps == 0

label var hcps "CPS"
label var hcen "Census"



#delimit ;


*This one is black and white

  #delimit ;
  twoway connected hcps hcen y, c(l)
  msymbol(O T S D)
  msize(med med large medlarge)
  clpattern(ll) clcolor(gs0 gs0) mcolor(gs0 gs0) graphregion(fcolor(gs16)) plotregion(style(none))
  xlabel(#15) title("Figure 2. Percent Homogamous by Data Source", size(medlarge) color(gs0)) sub("Prevailing Marriages, U.S. 1940-2003")
     ytitle("Percent (%)") xtitle("Year") ysc(r(40 65)) ylabel(40(5)65)
       note("SOURCES: Current Population Survey (CPS) and Census data."
          "NOTE: Education categories are lt 10, 10-11, 12, 13-15, 16, and gt 16 years of schooling.") ;

   cd "F:\Schwartz\cps_historical\graphs" ;
   graph export desc_d1.wmf, replace ;

  list if cps == 0 | y ==2003;



restore ;

#delimit cr


preserve

    keep h y WEIGHT cps freq hedc_d wedc_d

    local i = 1
     while `i' <= 6 {
      gen     h`i' = 1 if hedc_d == `i' & wedc_d == `i'
      replace h`i' = 0 if h`i' ~= 1 & (hedc_d == `i' | wedc_d == `i')
    local i = `i' + 1
    }


    collapse h1 h2 h3 h4 h5 h6 [w=WEIGHT], by(y cps)

for num 1/6: quietly replace hX = hX*100

foreach num of numlist 1/6 {
 quietly gen h`num'cps = h`num' if cps == 1
 quietly gen h`num'cen = h`num' if cps == 0
}


lab var h1cen "lt10"
lab var h2cen "10-11"
lab var h3cen "12"
lab var h4cen "13-15"
lab var h5cen "16"
lab var h6cen "gt16"


#delimit ;


*This one is black and white

  #delimit ;
  twoway connected h1cen h2cen h3cen h4cen h5cen h6cen y, c(l)
  msymbol(O T S D)
  msize(med med large medlarge)
  clpattern(ll) clcolor(gs0 gs0) mcolor(gs0 gs0) graphregion(fcolor(gs16)) plotregion(style(none))
  xlabel(#15) title("Figure 3. Percent Homogamous", size(medlarge) color(gs0)) sub("Prevailing Marriages, U.S. 1940-2003")
  ytitle("Percent (%)") xtitle("Year")
  note("SOURCES: Current Population Survey (CPS) and Census data")  ;

   cd "F:\Schwartz\cps_historical\graphs" ;
   graph export desc_d2.wmf, replace ;



restore ;





#delimit cr


preserve

    keep hyp h y WEIGHT cps freq

    keep if h ~= 1

    collapse hyp [w=WEIGHT], by(y cps)

replace h = h*100

gen hcps = hyp if cps == 1
gen hcen = hyp if cps == 0

label var hcps "CPS"
label var hcen "Census"



#delimit ;


*This one is black and white

  #delimit ;
  twoway connected hcps hcen y, c(l)
  msymbol(O T S D)
  msize(med med large medlarge)
  clpattern(ll) clcolor(gs0 gs0) mcolor(gs0 gs0) graphregion(fcolor(gs16)) plotregion(style(none))
  xlabel(#15) title("Figure 1. Percent Hypergamous, Given Heterogamy by Data Source", size(medlarge) color(gs0)) sub("Prevailing Marriages, U.S. 1940-2003")
  ytitle("Percent (%)") xtitle("Year")
       note("SOURCES: Current Population Survey (CPS) and Census data."
          "NOTE: Education categories are lt 10, 10-11, 12, 13-15, 16, and gt 16 years of schooling.") ;

   cd "F:\Schwartz\cps_historical\graphs" ;
   graph export desc_d4.wmf, replace ;

  list ;


restore ;

#delimit cr

preserve

    keep d2 y WEIGHT cps freq

    collapse d2 [w=WEIGHT], by(y cps)

replace d2 = d2*100

gen d2cps = d2 if cps == 1
gen d2cen = d2 if cps == 0

label var d2cps "CPS"
label var d2cen "Census"



#delimit ;


*This one is black and white

  #delimit ;
  twoway connected d2cps d2cen y, c(l)
  msymbol(O T S D)
  msize(med med large medlarge)
  clpattern(ll) clcolor(gs0 gs0) mcolor(gs0 gs0) graphregion(fcolor(gs16)) plotregion(style(none))
  xlabel(#15) title("Figure 3. Percent Crossing 2 or More Categories", size(medlarge) color(gs0)) sub("Prevailing Marriages, U.S. 1940-2003")
  ytitle("Percent (%)") xtitle("Year") ysc(r(0 25)) ylabel(0(5)25, grid)
       note("SOURCES: Current Population Survey (CPS) and Census data."
          "NOTE: Education categories are lt 10, 10-11, 12, 13-15, 16, and gt 16 years of schooling.") ;

   cd "F:\Schwartz\cps_historical\graphs" ;
   graph export desc_d5.wmf, replace ;

  list if cps == 0 ;


restore ;


log close ;



